==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/heo35.h <==
/* @lastChanged: "1998-10-21  9:40"
 * @filename:    heo35.h
 * @purpose:     "DCOMx_Functions"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */


#ifndef HEO35_H
#define HEO35_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC void vdcom_iid_ilivecachespec ( tsp00_C16*      pIId );
externC void vdcom_co_get_classobject ( bool            fDebug,
                                        void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext );
externC void vdcom_co_create_instance ( void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext );

externC void vdcom_paraminfo          ( bool            fDebug,
                                        void            *pParamInfo,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext );
externC void vdcom_create_instance    ( bool            fDebug,
                                        void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext );

externC void vdcom_release_instance   ( void            *pParamInfo,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext );



externC void vdcom_release_all        ( void );
externC void vdcom_dispatch           ( void            *pParamInfo );
externC void vdcom_dbproc             ( void            *pParamInfo );
externC void vdcom_get_dispaddr       ( void            *pInstance );
externC void vdcom_init_sink          ( void            *pInstance );
externC void vdcom_invalidate         ( void            *pInstance );
externC bool sql35_VDCOMiRequest ( tsp00_Uint4      ReqType, 
                                   void             *pParamInfo,
                                   tsp00_ErrText    VAR_ARRAY_REF Errtext );
#if defined(WIN32)
externC void sql35_VDCOMTransfer ( void             *pTransferBuffer,
                                   bool             *pOk,
                                   tsp00_ErrText    *pErrtext );
externC bool sql35_RemoveDCOMi ( void );
externC void sql35_DCOM0 ( void );
#endif  

#endif  /* HEO35_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/heo35.h <==
/* @lastChanged: "1998-10-21  9:40"
 * @filename:    heo35.h
 * @purpose:     "DCOMx_Functions"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */


#ifndef HEO35_H
#define HEO35_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC void vdcom_iid_ilivecachespec ( tsp00_C16       *pIId );
externC void vdcom_co_get_classobject ( void            *pInstance );
externC void vdcom_paraminfo          ( void            *pParamInfo );
externC void vdcom_create_instance    ( void            *pInstance );
externC void vdcom_release_instance   ( void            *pParamInfo );
externC void vdcom_release_all        ( void );
externC void vdcom_dbproc             ( void            *pParamInfo );
externC void vdcom_get_dispaddr       ( void            *pInstance );
externC void vdcom_init_sink          ( void            *pInstance );
externC void vdcom_invalidate         ( void            *pInstance );

#endif  /* HEO35_H */
